TemplateFolders
Templates
Export
Export specified template folder to a specified format
User with Execute Export permission on template folder and Create Entity on an export folder can access this method.
Request
POST /api/rp/v1/Templates/Folder/{id}/Export
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| *id | string | template folder id |
|
| body | export parameters (string only) |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 200 | Specified template folder has been exported |
|
| 400 | Template folder Id is null |
|
| 403 | You don't have permissions for the operation |
|
| 402 | Subscription is outdated |
|
| 404 | Exports folder not found |
Prepare
Prepare specified template folder to report folder
User with Execute Prepare permission on report and Create Entity on a prepared report folder can access this method.
Request
POST /api/rp/v1/Templates/Folder/{id}/Prepare
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| *id | string | template id |
|
| body | Template folder prepare view model |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 200 | Specified template folder has been prepared |
|
| 400 | Template folder Id is null |
|
| 403 | You don't have permissions for the operation |
|
| 402 | subscription is outdated |
|
| 404 | Template or report folder not found |
GetPermissions
Get all folder permissions
Request
GET /api/rp/v1/Templates/Folder/{id}/permissions
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| *id | string |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 200 | Success |
|
| 400 | Parameters did not pass the validation |
|
| 402 | Subscription is blocked |
|
| 403 | You don't have permissions for the operation |
|
| 404 | Folder or subscription not found |
GetMyPermissions
Get user's permissions for a folder by id
Request
GET /api/rp/v1/Templates/Folder/{folderId}/mypermissions
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| *folderId | string | folder id |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 200 | Succes |
|
| 400 | Provided parameters did not pass the validation |
UpdatePermissions
Update permissions
Request
POST /api/rp/v1/Templates/{id}/permissions
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| *id | string | folder id |
|
| body | new permissions VM |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 204 | Success |
|
| 400 | Parameters did not pass the validation |
|
| 402 | Subscription is outdated |
|
| 403 | You don't have permissions for the operation |
|
| 404 | Folder or subscription not found |
DeleteFolder
Delete specified folder
User with a Delete Entity permission can access this method.
Request
DELETE /api/rp/v1/Templates/Folder/{id}
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| *id | string | folder id |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 204 | Success |
|
| 400 | Parameters did not pass the validation |
|
| 402 | Subscription is outdated |
|
| 403 | You don't have permissions for the operation |
|
| 404 | Folder or subscription not found |
GetFolder
Get specified folder
User with a Get Entity permission can access this method.
Request
GET /api/rp/v1/Templates/Folder/{id}
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| *id | string | folder id |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 200 | Success |
|
| 400 | Parameters did not pass the validation |
|
| 402 | Subscription is blocked |
|
| 403 | You don't have permissions for the operation |
|
| 404 | Folder or subscription not found |
MoveFolderToBin
Move specified folder to recycle bin
User with a Delete Entity permission can access this method.
Request
DELETE /api/rp/v1/Templates/Folder/{id}/ToBin
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| *id | string | folder id |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 204 | Success |
|
| 400 | Parameters did not pass the validation |
|
| 402 | Subscription is outdated |
|
| 403 | You don't have permissions for the operation |
|
| 404 | Folder or subscription not found |
RecoverFolder
Recover specified folder
User with a Create RecycleBin permission can access this method.
Request
POST /api/rp/v1/Templates/Folder/{id}/Recover[?recoveryPath]
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| *id | string | folder id |
|
| recoveryPath | string | id of the folder, that recovered folder should be placed in |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 204 | Success |
|
| 400 | Parameters did not pass the validation |
|
| 402 | Subscription is outdated |
|
| 403 | You don't have permissions for the operation |
|
| 404 | Folder or subscription not found |
GetBreadcrumbs
Get specified folder breadcrumbs
User with a Get Entity permission can access this method.
Request
GET /api/rp/v1/Templates/Folder/{id}/Breadcrumbs
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| *id | string | folder id |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 200 | Success |
|
| 400 | Parameters did not pass the validation |
|
| 402 | Subscription is blocked |
|
| 403 | You don't have permissions for the operation |
|
| 404 | Folder or subscription not found |
CalculateFolderSize
Get specified folder, calculate it's size
User with a Get Entity permission can access this method.
Request
GET /api/rp/v1/Templates/Folder/{id}/size
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| *id | string | folder id |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 200 | Success |
|
| 400 | Parameters did not pass the validation |
|
| 402 | Subscription is blocked |
|
| 403 | You don't have permissions for the operation |
|
| 404 | Folder or subscription not found |
GetOrCreate
Get specified folder
User with a Get (and/or Create) Entity permission can access this method.
Request
GET /api/rp/v1/Templates/Folder/getOrCreate[?name&subscriptionId&parentId]
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| name | string | folder name |
|
| subscriptionId | string | subscriptionId |
|
| parentId | string | parent folder id |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 200 | Success |
|
| 400 | Parameters did not pass the validation |
|
| 402 | Subscription is blocked or outdated |
|
| 403 | You don't have permissions for the operation |
|
| 404 | Folder or subscription not found |
GetFolders
Get all folders from specified folder
User with a Get Entity permission can access this method.
Request
GET /api/rp/v1/Templates/Folder/{id}/ListFolders[?skip&take&orderBy&desc&searchPattern&useRegex]
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| *id | string | folder id |
|
| skip | integer | 0 | number of folder and files to skip |
| take | integer | 10 | number of folder and files to take |
| orderBy | a field to sort by |
||
| desc | boolean | False | if true - sorting will be done in the descending order, otherwise - ascending |
| searchPattern | string | search pattern used to only include matching files in the result |
|
| useRegex | boolean | False | set this to true if you want to use regular expression to search |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 200 | Success |
|
| 400 | Parameters did not pass the validation |
|
| 402 | Subscription is blocked |
|
| 403 | You don't have permissions for the operation |
|
| 404 | Folder or subscription not found |
GetFoldersCount
Get count of folders what contains in a specified folder
User with a Get Count permission can access this method.
Request
GET /api/rp/v1/Templates/Folder/{id}/CountFolders
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| *id | string | folder id |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 200 | Success |
|
| 400 | Parameters did not pass the validation |
|
| 402 | Subscription is blocked |
|
| 403 | You don't have permissions for the operation |
|
| 404 | Folder or subscription not found |
GetRootFolder
Get workspace's root folder
Request
GET /api/rp/v1/Templates/Root[?subscriptionId]
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| subscriptionId | string |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 200 | Success |
|
| 400 | Parameters did not pass the validation |
|
| 402 | Subscription is blocked |
|
| 403 | You don't have permissions for the operation |
|
| 404 | Folder or subscription not found |
MoveFolder
Move folder into a specified folder
User with a Update Place permission for a folder and Create Entity for a destination Folder can access this method.
Request
POST /api/rp/v1/Templates/Folder/{id}/Move/{folderId}
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| *id | string | folder id |
|
| *folderId | string | destination folder id |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 200 | Success |
|
| 400 | Parameters did not pass the validation |
|
| 402 | Subscription is outdated |
|
| 403 | You don't have permissions for the operation |
|
| 404 | Folder or subscription not found |
CopyFolder
Move folder to a specified folder
User with a Update Place permission for a folder and Create Entity for a Parent Folder can access this method.
Request
POST /api/rp/v1/Templates/Folder/{id}/Copy/{folderId}
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| *id | string | moving folder id |
|
| *folderId | string | destination folder id |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 200 | Success |
|
| 400 | Parameters did not pass the validation |
|
| 402 | Subscription is outdated |
|
| 403 | You don't have permissions for the operation |
|
| 404 | Folder or subscription not found |
PostFolder
Create folder
User with a Create Entity permission can access this method.
Request
POST /api/rp/v1/Templates/Folder/{id}/Folder
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| *id | string | Identifier of parent folder id |
|
| body | create VM |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 200 | New folder has been created) |
|
| 400 | Parent folder id or VM is not valid |
|
| 402 | subscription is outdated |
|
| 403 | You don't have permissions for the operation |
|
| 404 | parent folder/subscription not found |
RenameFolder
Rename a folder
User with a Update Name permission can access this method.
Request
PUT /api/rp/v1/Templates/Folder/{id}/Rename
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| *id | string | User with a Update Name permission can access this method. |
|
| body | User with a Update Name permission can access this method. |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 200 | Folder name has been updated |
|
| 400 | folderId or VM is not valid |
|
| 402 | subscription is outdated |
|
| 403 | You don't have permissions for the operation |
|
| 404 | Folder or subscription not found |
UpdateIcon
Update a folder's icon
User with a Update Icon permission can access this method.
Request
PUT /api/rp/v1/Templates/Folder/{id}/Icon
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| *id | string | Identifier of folder |
|
| body | Update icon model |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 200 | Folder's icon has been updated |
|
| 400 | folderId or VM is not valid |
|
| 402 | subscription is outdated |
|
| 403 | You don't have permissions for the operation |
|
| 404 | Folder or subscription not found |
UpdateTags
Update tags
User with a Update Tags permission can access this method.
Request
PUT /api/rp/v1/Templates/Folder/{id}/UpdateTags
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| *id | string | User with a Update Tags permission can access this method. |
|
| body | User with a Update Tags permission can access this method. |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 200 | Tags has been updated |
|
| 400 | folderId or Tags is null |
|
| 403 | You don't have permissions for the operation |
|
| 402 | subscription is outdated |
|
| 404 | Folder or subscription not found |
Definitions
ExportTemplateVM
| Name | Type | Notes |
|---|---|---|
| fileName | string | |
| folderId | string | |
| locale | string | |
| pagesCount | integer (int32) | |
| format |
|
|
| exportParameters | object | |
| reportParameters | object | |
| $t | string |
ExportFormat
Enum Values
PdfHtml
Mht
Image
Biff8
Csv
Dbf
Json
LaTeX
Odt
Ods
Docx
Pptx
Xlsx
Xps
Ppml
PS
Richtext
Svg
Text
Xaml
Xml
Zpl
FileVM
| Name | Type | Notes |
|---|---|---|
| id | string | |
| createdTime | string (date-time) | |
| creatorUserId | string | |
| editedTime | string (date-time) | |
| editorUserId | string | |
| name | string | |
| parentId | string | |
| tags | array | |
| icon | string (byte) | |
| type |
|
|
| size | integer (int64) | |
| subscriptionId | string | |
| status |
|
|
| statusReason |
|
|
| errorMessage | string | |
| isDeleted | boolean | |
| platform |
|
|
| $t | string |
FileType
Enum Values
FileFolder
FileStatus
Enum Values
NoneInQueue
InProcess
Success
Failed
FileStatusReason
Enum Values
NoneAllRight
Hang
Error
NotFound
NotEnoughSpace
ExportStarted
PreparationStarted
CrashLoop
ReportPlatform
Enum Values
UnknownNET
VCL
ProblemDetails
| Name | Type | Notes |
|---|---|---|
| type | string | |
| title | string | |
| status | integer (int32) | |
| detail | string | |
| instance | string |
PrepareTemplateVM
| Name | Type | Notes |
|---|---|---|
| name | string | |
| locale | string | |
| folderId | string | |
| pagesCount | integer (int32) | |
| reportParameters | object | |
| $t | string |
FilePermissionsVM
| Name | Type | Notes |
|---|---|---|
| permissions |
|
|
| $t | string |
FilePermissionsCRUDVM
| Name | Type | Notes |
|---|---|---|
| ownerId | string | |
| owner |
|
|
| groups | object | |
| other |
|
|
| anon |
|
|
| $t | string |
FilePermissionCRUDVM
| Name | Type | Notes |
|---|---|---|
| create |
|
|
| delete |
|
|
| execute |
|
|
| get |
|
|
| update |
|
|
| administrate |
|
|
| $t | string |
FileCreate
FileDelete
FileExecute
FileGet
FileUpdate
FileAdministrate
UpdateFilePermissionsVM
| Name | Type | Notes |
|---|---|---|
| newPermissions |
|
|
| administrate |
|
|
| $t | string |
BreadcrumbsVM
| Name | Type | Notes |
|---|---|---|
| breadcrumbs |
|
|
| $t | string |
BreadcrumbsModel
| Name | Type | Notes |
|---|---|---|
| id | string | |
| name | string |
FolderSizeVM
| Name | Type | Notes |
|---|---|---|
| size | integer (int64) | |
| realSize | integer (int64) | |
| documentsCount | integer (int64) | |
| $t | string |
FilesVM
| Name | Type | Notes |
|---|---|---|
| $t | string | |
| files |
|
|
| count | integer (int64) | |
| skip | integer (int32) | |
| take | integer (int32) |
CountVM
| Name | Type | Notes |
|---|---|---|
| count | integer (int64) | |
| $t | string |
TemplateFolderCreateVM
| Name | Type | Notes |
|---|---|---|
| $t | string | |
| name | string | |
| tags | array | |
| icon | string (byte) |
FolderRenameVM
| Name | Type | Notes |
|---|---|---|
| name | string | |
| $t | string |
FolderIconVM
| Name | Type | Notes |
|---|---|---|
| icon | string (byte) | |
| $t | string |
FolderTagsUpdateVM
| Name | Type | Notes |
|---|---|---|
| tags | array | |
| $t | string |